@@ -9,25 +9,30 @@ describe 'neutron::plugins::ovs::opendaylight' do
      class { 'neutron::server': }
      class { 'neutron':
       rabbit_password => 'passw0rd',
-      core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
+      core_plugin     => 'ml2' }"
   end
 
   let :default_params do
     {
-      :odl_username       => 'admin',
-      :odl_password       => 'admin',
-      :odl_check_url      => 'http://127.0.0.1:8080/restconf/operational/network-topology:network-topology/topology/netvirt:1',
-      :odl_ovsdb_iface    => 'tcp:127.0.0.1:6640',
-      :ovsdb_server_iface => 'ptcp:6639:127.0.0.1',
-      :provider_mappings  => [],
-      :retry_interval     => 60,
-      :retry_count        => 20,
+      :odl_check_url         => 'http://127.0.0.1:8080/restconf/operational/network-topology:network-topology/topology/netvirt:1',
+      :odl_ovsdb_iface       => 'tcp:127.0.0.1:6640',
+      :ovsdb_server_iface    => 'ptcp:6639:127.0.0.1',
+      :provider_mappings     => [],
+      :retry_interval        => 60,
+      :retry_count           => 20,
+      :host_id               => "dummy_host",
+      :allowed_network_types => ['local', 'vlan', 'vxlan', 'gre'],
+      :enable_dpdk           => false,
+      :vhostuser_socket_dir  => '/var/run/openvswitch',
+      :vhostuser_mode        => 'client'
     }
   end
 
   let :params do
     {
-      :tunnel_ip         => '127.0.0.1',
+      :tunnel_ip          => '127.0.0.1',
+      :odl_username       => 'user',
+      :odl_password       => 'password',
     }
   end
 
@@ -50,6 +55,13 @@ describe 'neutron::plugins::ovs::opendaylight' do
       end
       it_configures 'with provider mappings'
     end
+
+    context 'with DPDK enabled' do
+      before do
+        params.merge!({ :enable_dpdk => true })
+      end
+      it_configures 'with DPDK enabled'
+    end
     it_configures 'with default parameters'
   end
 
@@ -57,8 +69,10 @@ describe 'neutron::plugins::ovs::opendaylight' do
     it 'configures OVS for ODL' do
       is_expected.to contain_exec('Wait for NetVirt OVSDB to come up')
       is_expected.to contain_exec('Set OVS Manager to OpenDaylight')
-      is_expected.to contain_exec('Set local_ip Other Option')
-      is_expected.not_to contain_exec('Set provider_mappings Other Option')
+      is_expected.to contain_vs_config('other_config:local_ip')
+      is_expected.not_to contain_vs_config('other_config:provider_mappings')
+      is_expected.to contain_vs_config('external_ids:odl_os_hostconfig_hostid')
+      is_expected.to contain_vs_config('external_ids:odl_os_hostconfig_config_odl_l2')
     end
   end
 
@@ -66,8 +80,25 @@ describe 'neutron::plugins::ovs::opendaylight' do
     it 'configures OVS for ODL' do
       is_expected.to contain_exec('Wait for NetVirt OVSDB to come up')
       is_expected.to contain_exec('Set OVS Manager to OpenDaylight')
-      is_expected.to contain_exec('Set local_ip Other Option')
-      is_expected.to contain_exec('Set provider_mappings Other Option')
+      is_expected.to contain_vs_config('other_config:local_ip')
+      is_expected.to contain_vs_config('other_config:provider_mappings')
+      is_expected.to contain_vs_config('external_ids:odl_os_hostconfig_hostid')
+      is_expected.to contain_vs_config('external_ids:odl_os_hostconfig_config_odl_l2').with(
+        :value => /bridge_mappings\": {\"default\":\"br-ex\"}/
+      )
+    end
+  end
+
+  shared_examples_for 'with DPDK enabled' do
+    it 'configures OVS for ODL' do
+      is_expected.to contain_exec('Wait for NetVirt OVSDB to come up')
+      is_expected.to contain_exec('Set OVS Manager to OpenDaylight')
+      is_expected.to contain_vs_config('other_config:local_ip')
+      is_expected.not_to contain_vs_config('other_config:provider_mappings')
+      is_expected.to contain_vs_config('external_ids:odl_os_hostconfig_hostid')
+      is_expected.to contain_vs_config('external_ids:odl_os_hostconfig_config_odl_l2').with(
+        :value => /vhostuser/,
+      )
     end
   end
 
